# -*- encoding: utf-8 -*-

import os
import djangorecipe
from djangorecipe.recipe import Recipe as OriginalDjangoRecipe

################################################################################
# SETTINGS
################################################################################
production_settings = '''
from %(project)s.settings import *
'''

development_settings = '''
from %(project)s.settings import *
DEBUG=True
TEMPLATE_DEBUG=DEBUG
'''

urls_template = '''
from django.conf.urls.defaults import patterns, include, handler500
from django.conf import settings
from django.contrib import admin
admin.autodiscover()

handler500 # Pyflakes

urlpatterns = patterns(
    '',
    (r'^admin/(.*)', admin.site.root),
    (r'^accounts/login/$', 'django.contrib.auth.views.login'),
)

if settings.DEBUG:
    urlpatterns += patterns('',
        (r'^media/(?P<path>.*)$', 'django.views.static.serve',
         {'document_root': settings.MEDIA_ROOT}),
    )
'''

auf_settings_template = '''# -*- encoding: utf-8 -*-

import os
import socket
from conf import *

# Rapports d'erreurs
EMAIL_SUBJECT_PREFIX = '[%(project)s - %%s] ' %% socket.gethostname()
ADMINS = (
    ('Équipe ARI-SI', 'developpeurs@ca.auf.org'),
)

MANAGERS = ADMINS

TIME_ZONE = 'Canada/Montreal'

LANGUAGE_CODE = 'fr-ca'

# Absolute path to the directory that holds media.
# Example: "/home/media/media.lawrence.com/"
MEDIA_ROOT = %(media_root)s

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash if there is a path component (optional in other cases).
# Examples: "http://media.lawrence.com", "http://example.com/media/"
MEDIA_URL = '/media/'

# Contient les fichiers envoyés par les utilisateurs
UPLOAD_ROOT = os.path.join(%(media_root)s, 'upload')
UPLOAD_URL = os.path.join(MEDIA_URL, 'upload')


# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
# trailing slash.
# Examples: "http://foo.com/media/", "/media/".
ADMIN_MEDIA_PREFIX = '/admin_media/'

# Don't share this with anybody.
SECRET_KEY = '%(secret)s'

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.middleware.doc.XViewMiddleware',
)

ROOT_URLCONF = '%(urlconf)s'


INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.admin',
)

TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.load_template_source',
    'django.template.loaders.app_directories.load_template_source',
)

TEMPLATE_DIRS = (
    os.path.join(os.path.dirname(__file__), "templates"),
)


'''
djangorecipe.recipe.settings_template = auf_settings_template

################################################################################
# DEVELOPPEMENT
################################################################################
auf_development_settings = '''# -*- encoding: utf-8 -*-

from %(project)s.settings import *
DEBUG=True
TEMPLATE_DEBUG=DEBUG

# Décommentez ces lignes pour activer la debugtoolbar
#INTERNAL_IPS = ('127.0.0.1',)
#INSTALLED_APPS += ('debug_toolbar',)
#MIDDLEWARE_CLASSES += ('debug_toolbar.middleware.DebugToolbarMiddleware',)

AUTH_PASSWORD_REQUIRED = False
'''
djangorecipe.recipe.development_settings = auf_development_settings


################################################################################
# PRODUCTION
################################################################################
auf_production_settings = ''' # -*- encoding: utf-8 -*-

# En production, rediriger la sortie terminal on disponible en WSGI
# vers la sortie fichier errorlog.
import sys
sys.stdout = sys.stderr

from %(project)s.settings import *
'''
djangorecipe.recipe.production_settings = auf_production_settings

class Recipe(OriginalDjangoRecipe):

    def __init__(self, buildout, name, options):
        return super(Recipe, self).__init__(buildout, name, options)

    def create_project(self, project_dir):
        super(Recipe, self).create_project(project_dir)
        os.mkdir(os.path.join(project_dir, 'media', 'css'))
        os.mkdir(os.path.join(project_dir, 'media', 'images'))
        os.mkdir(os.path.join(project_dir, 'media', 'js'))
        os.mkdir(os.path.join(project_dir, 'media', 'upload'))
